"""
Module provides an endpoint for creating dump-file for luna-configurator based on service names or profile names.
"""

import argparse
import datetime

from .dump.base_configuration_dump import createDump
from .dump.services import LUNA_PLATFORM


def getArgs() -> argparse.Namespace:
    """
    Collects passed arguments
        --services
        --dump-file
        --platform

    Returns:
        object with arguments and its values

    """
    parser = argparse.ArgumentParser(description="Create configurator dump file")
    parser.add_argument(
        "--services",
        metavar="services",
        type=str,
        default=[],
        nargs="+",
        choices=LUNA_PLATFORM,
        help="Services for generating a file (separated by spaces)",
    )
    parser.add_argument(
        "--dump-file",
        metavar="filename",
        type=str,
        default=f"luna-configurator-dump-{datetime.datetime.now().strftime('%Y-%m-%dT%H-%M-%S')}.json",
        help="path to the result file",
    )
    cmlArgs = parser.parse_args()

    if len(cmlArgs.services) == 0 and len(cmlArgs.profile) == 0:
        raise ValueError("Specify at least one of the keys --services or --profile")

    return cmlArgs


if __name__ == "__main__":
    CMD_ARGS = getArgs()
    createDump(CMD_ARGS.services, CMD_ARGS.dump_file)
