"""
Module is entry point for migration generation
"""

import os
from argparse import ArgumentParser, Namespace

from configs_core.migration.migrate import MigrationProcessor

from .config import MIGRATION_DIR
from .dump.services import LUNA_PLATFORM
from .services.configs import SettingsConfigs


def getCmdOptions() -> Namespace:
    """
    Collects passed arguments
        --migration name
        --config - path to config file
        --luna-config - luna-configurator address

    Returns:
        object with arguments and its values
    """
    parser = ArgumentParser(description="Configs migration generator")
    parser.add_argument(
        "target",
        metavar="target",
        type=str,
        nargs=1,
        help="target revision: revision hash or 'head' - update to newest or '-1' - downgrade current"
        " or init to initialize empty database",
    )
    defaultConfigFilePath = os.path.join(os.path.abspath(os.path.dirname(__file__)), "config.conf")
    parser.add_argument("--config", default=defaultConfigFilePath, type=str, help="path to config")

    return parser.parse_args()


if __name__ == "__main__":
    CMD_ARGS = getCmdOptions()
    CONFIG = SettingsConfigs()
    CONFIG.load(configuratorAddress=None, configFile=CMD_ARGS.config, tags={})
    MigrationProcessor(
        dbUrl=CONFIG.db.dbUrl,
        migration=MIGRATION_DIR,
        services=LUNA_PLATFORM,
        component="platform",
    ).migrate(targetRevision=CMD_ARGS.target[0])
