"""

Configs migration



Generation datetime: 2021-04-08 09:28:50.864062

"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "b0aa563f"

DOWN_REVISION = "27a016ed"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_DETECTOR_TYPE",
        oldValidationSchema={
            "type": "string",
            "enum": ["FACE_DET_V1", "FACE_DET_V2", "FACE_DET_V3"],
        },
        newValidationSchema={"type": "string", "enum": ["FACE_DET_V3"]},
        settingUpgradeFunction=lambda faceDet: "FACE_DET_V3",
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to remove

    mh.removeLimitation(limitationName="FACE_DETECTOR_V1")

    mh.removeLimitation(limitationName="FACE_DETECTOR_V2")

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify

    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to add

    mh.addLimitation(
        limitationName="FACE_DETECTOR_V1",
        validationSchema={
            "type": "object",
            "properties": {
                "min_face_size": {"type": "integer", "minimum": 1},
                "scale_factor": {"type": "number"},
                "use_lnet": {"type": "boolean"},
            },
            "description": "settings for face detector version 1 and 2",
            "additionalProperties": False,
        },
        defaultValue={"min_face_size": 50, "scale_factor": 0.7, "use_lnet": True},
        description="face detector version 1 settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )

    mh.addLimitation(
        limitationName="FACE_DETECTOR_V2",
        validationSchema={
            "type": "object",
            "properties": {
                "min_face_size": {"type": "integer", "minimum": 1},
                "scale_factor": {"type": "number"},
                "use_lnet": {"type": "boolean"},
            },
            "description": "settings for face detector version 1 and 2",
            "additionalProperties": False,
        },
        defaultValue={"min_face_size": 50, "scale_factor": 0.7, "use_lnet": True},
        description="face detector version 2 settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
