"""
Configs migration

Generation datetime: 2023-04-24 08:24:26.118794
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "35ddecdf"
DOWN_REVISION = "6a04d0d3"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_EVENTS_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins",
        newDescription="list of luna-events active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-events"],
        newServices=["luna-events"],
    ),
    LimitationToModify(
        limitationName="LUNA_ACCOUNTS_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins for luna-accounts",
        newDescription="list of luna-accounts active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-accounts"],
        newServices=["luna-accounts"],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins",
        newDescription="list of luna-handlers active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
    LimitationToModify(
        limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=107,
        newDefaultValue=107,
        oldDescription="default human descriptor version to work with",
        newDescription="default human descriptor version to work with",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        newServices=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_SENDER_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-sender",
        newDescription="list of luna-sender active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-sender"],
        newServices=["luna-sender"],
    ),
    LimitationToModify(
        limitationName="LUNA_API_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins",
        newDescription="list of luna-api active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api"],
        newServices=["luna-api"],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-faces",
        newDescription="list of luna-faces active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-faces"],
        newServices=["luna-faces"],
    ),
    LimitationToModify(
        limitationName="LUNA_BACKPORT4_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins",
        newDescription="list of luna-backport4 active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport4"],
        newServices=["luna-backport4"],
    ),
    LimitationToModify(
        limitationName="LUNA_TASKS_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-tasks",
        newDescription="list of luna-tasks active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-tasks"],
    ),
    LimitationToModify(
        limitationName="INFLUX_MONITORING",
        oldValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        newValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        oldDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        newDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        oldDescription="monitoring parameters",
        newDescription="monitoring parameters",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-sender",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-image-store",
        newDescription="list of luna-image-store active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-image-store"],
        newServices=["luna-image-store"],
    ),
    LimitationToModify(
        limitationName="LUNA_BACKPORT3_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins",
        newDescription="list of luna-backport3 active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport3"],
        newServices=["luna-backport3"],
    ),
    LimitationToModify(
        limitationName="LUNA_ADMIN_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins for luna-admin",
        newDescription="list of luna-admin active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin"],
        newServices=["luna-admin"],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-python-matcher",
        newDescription="list of luna-python-matcher active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-python-matcher"],
        newServices=["luna-python-matcher"],
    ),
    LimitationToModify(
        limitationName="LUNA_LICENSES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        oldDescription="LUNA Licenses address",
        newDescription="LUNA Licenses address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-faces", "luna-handlers"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-handlers",
            "luna-remote-sdk",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_LICENSES_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-licenses",
        newDescription="list of luna-licenses active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-licenses"],
        newServices=["luna-licenses"],
    ),
    LimitationToModify(
        limitationName="LUNA_MATCHER_PROXY_ACTIVE_PLUGINS",
        oldValidationSchema={"type": "array", "items": {"type": "string"}},
        newValidationSchema={"type": "array", "items": {"type": "string"}},
        oldDefaultValue=[],
        newDefaultValue=[],
        oldDescription="list active plugins of luna-matcher-proxy",
        newDescription="list of luna-matcher-proxy active plugins",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-matcher-proxy"],
        newServices=["luna-matcher-proxy"],
    ),
    LimitationToModify(
        limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=59,
        newDefaultValue=59,
        oldDescription="default face descriptor version to work with",
        newDescription="default face descriptor version to work with",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        newServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # init lrs
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-remote-sdk active plugins",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Remote Sdk http settings",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Remote Sdk logger settings",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_LOGGER")
