"""
Configs migration

Generation datetime: 2023-06-21 14:30:29.435343
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "31159b58"
DOWN_REVISION = "365f0ef5"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_LICENSES_ADDRESS",
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-handlers",
            "luna-remote-sdk",
        ],
        newServices=["luna-admin", "luna-api", "luna-faces", "luna-remote-sdk"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
