"""
Configs migration

Generation datetime: 2023-07-13 08:04:25.352543
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "d6a13b60"
DOWN_REVISION = "f9c5c1fb"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_PEOPLE_COUNT_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-remote-sdk settings for people count estimation",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_PEOPLE_COUNT_ESTIMATOR_SETTINGS")
