"""
Configs migration

Generation datetime: 2023-11-02 11:59:19.381448
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "658d2427"
DOWN_REVISION = "00cf21b7"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_SENDER_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        newDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        oldDescription="LUNA Sender address",
        newDescription="LUNA Sender address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-lambda-unit"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5220", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5220", "api_version": 1},
        oldDescription="Address of service for remote image estimation",
        newDescription="Address of service for remote image estimation",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-lambda-unit"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-remote-sdk service",
        newDescription="timeouts for http-request to luna-remote-sdk service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_TASKS_TO_MATCHER_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 300,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 300,
        },
        newDefaultValue={
            "request": 300,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 300,
        },
        oldDescription="timeouts for http-request to LUNA Matcher entry point service",
        newDescription="timeouts for http-request to LUNA Matcher entry point service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-bodies-samples",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-bodies-samples",
        },
        oldDescription="Address of service for storing bodies samples",
        newDescription="Address of service for storing bodies samples",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_TASKS_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres", "oracle"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": ["db_type", "db_settings"],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres", "oracle"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": ["db_type", "db_settings"],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        newDefaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        oldDescription="Main database for luna-tasks service",
        newDescription="Main database for luna-tasks service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_EVENTS_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-events service",
        newDescription="timeouts for http-request to luna-events service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-lambda-unit", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-objects",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-objects",
        },
        oldDescription="Address of service for storing objects",
        newDescription="Address of service for storing objects",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-tasks"],
        newServices=["luna-api", "luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="TASKS_TO_HANDLERS_CONCURRENCY",
        oldValidationSchema={"type": "integer", "minimum": 0},
        newValidationSchema={"type": "integer", "minimum": 0},
        oldDefaultValue=8,
        newDefaultValue=8,
        oldDescription="Tasks to handlers extract request concurrency.",
        newDescription="Tasks to handlers extract request concurrency.",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5090", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5090", "api_version": 1},
        oldDescription="LUNA Handlers address",
        newDescription="LUNA Handlers address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-tasks"],
        newServices=["luna-admin", "luna-api", "luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="TASKS_REDIS_DB_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="TASKS_TO_IMAGE_STORE_REQUESTS_CONCURRENCY",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=100,
        newDefaultValue=100,
        oldDescription="Concurrency for requests to luna-image-store",
        newDescription="Concurrency for requests to luna-image-store",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="MAX_ERROR_COUNT_PER_TASK",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=100000,
        newDefaultValue=100000,
        oldDescription="Maximum errors count per task to store",
        newDescription="Maximum errors count per task to store",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5100", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5100", "api_version": 1},
        oldDescription="LUNA Python Matcher address",
        newDescription="LUNA Python Matcher address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_TASK_RESULT_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "task-result",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "task-result",
        },
        oldDescription="Address of service for storing task results",
        newDescription="Address of service for storing task results",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-tasks"],
        newServices=["luna-admin", "luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5030", "api_version": 3},
        newDefaultValue={"origin": "http://127.0.0.1:5030", "api_version": 3},
        oldDescription="LUNA Faces address",
        newDescription="LUNA Faces address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        oldDescription="Address of service for storing origin images",
        newDescription="Address of service for storing origin images",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-samples",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-samples",
        },
        oldDescription="Address of service for storing samples",
        newDescription="Address of service for storing samples",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-handlers service",
        newDescription="timeouts for http-request to luna-handlers service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-tasks"],
        newServices=["luna-api", "luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_TASKS_LOAD_EXTERNAL_ARCHIVE_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 100,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 100,
        },
        newDefaultValue={
            "request": 100,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 100,
        },
        oldDescription="timeouts for http-request to external resource for download archive",
        newDescription="timeouts for http-request to external resource for download archive",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="EXTERNAL_LUNA_API_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        newDefaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        oldDescription="external luna api address",
        newDescription="external luna api address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="TASKS_TO_FACES_REQUESTS_CONCURRENCY",
        oldValidationSchema={"type": "integer"},
        newValidationSchema={"type": "integer"},
        oldDefaultValue=5,
        newDefaultValue=5,
        oldDescription="Concurrency for requests to luna-faces",
        newDescription="Concurrency for requests to luna-faces",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="PLATFORM_LIMITS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "match": {
                    "type": "object",
                    "properties": {
                        "array_filter_limit": {"type": "integer", "minimum": 1},
                        "reference_limit": {"type": "integer", "minimum": 1},
                        "candidate_limit": {"type": "integer", "minimum": 1},
                        "result_candidate_limit": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "cross_match": {
                    "type": "object",
                    "properties": {
                        "short_array_filter_limit": {"type": "integer", "minimum": 1},
                        "array_filter_limit": {"type": "integer", "minimum": 1},
                        "result_candidate_limit": {"type": "integer", "minimum": 1},
                        "general_limit": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
            },
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "match": {
                    "type": "object",
                    "properties": {
                        "array_filter_limit": {"type": "integer", "minimum": 1},
                        "reference_limit": {"type": "integer", "minimum": 1},
                        "candidate_limit": {"type": "integer", "minimum": 1},
                        "result_candidate_limit": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "cross_match": {
                    "type": "object",
                    "properties": {
                        "short_array_filter_limit": {"type": "integer", "minimum": 1},
                        "array_filter_limit": {"type": "integer", "minimum": 1},
                        "result_candidate_limit": {"type": "integer", "minimum": 1},
                        "general_limit": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
            },
            "additionalProperties": False,
        },
        oldDefaultValue={
            "match": {
                "array_filter_limit": 1000,
                "reference_limit": 30,
                "candidate_limit": 30,
                "result_candidate_limit": 100,
            },
            "cross_match": {
                "short_array_filter_limit": 1000,
                "array_filter_limit": 20000,
                "result_candidate_limit": 20000,
                "general_limit": 100000,
            },
        },
        newDefaultValue={
            "match": {
                "array_filter_limit": 1000,
                "reference_limit": 30,
                "candidate_limit": 30,
                "result_candidate_limit": 100,
            },
            "cross_match": {
                "short_array_filter_limit": 1000,
                "array_filter_limit": 20000,
                "result_candidate_limit": 20000,
                "general_limit": 100000,
            },
        },
        oldDescription="platform limits",
        newDescription="platform limits",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-matcher-proxy", "luna-python-matcher", "luna-tasks"],
        newServices=[
            "luna-lambda-tasks-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_MATCHER_PROXY_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5110", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5110", "api_version": 1},
        oldDescription="LUNA Python Matcher Proxy address",
        newDescription="LUNA Python Matcher Proxy address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
        },
        oldDescription="whether to use nested optional services",
        newDescription="whether to use nested optional services",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_TASK_RESULT_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-tasks"],
        newServices=["luna-lambda-tasks-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-faces service",
        newDescription="timeouts for http-request to luna-faces service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
        newServices=[
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_EVENTS_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5040", "api_version": 2},
        newDefaultValue={"origin": "http://127.0.0.1:5040", "api_version": 2},
        oldDescription="LUNA Events address",
        newDescription="LUNA Events address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="INFLUX_MONITORING",
        oldValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        newValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        oldDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        newDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        oldDescription="monitoring parameters",
        newDescription="monitoring parameters",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_TASKS_UNIT_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-lambda-tasks-unit active plugins",
        services=["luna-lambda-tasks-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_TASKS_UNIT_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Lambda Tasks Unit http settings",
        services=["luna-lambda-tasks-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_TASKS_UNIT_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json", "ecs"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Lambda Tasks Unit logger settings",
        services=["luna-lambda-tasks-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_TASKS_UNIT_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to lambda unit",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_LAMBDA_TASKS_UNIT_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_TASKS_UNIT_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_TASKS_UNIT_LOGGER")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_TASKS_UNIT_TIMEOUTS")
