"""
Configs migration

Generation datetime: 2024-06-21 09:23:25.493023
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "6380e74e"
DOWN_REVISION = "5b4de77b"


limitationsToModify: list[LimitationToModify] = []

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="TASKS_TO_MATCHER_CONCURRENCY",
        validationSchema={"type": "integer", "minimum": 1},
        defaultValue=2,
        description="Tasks to matcher request concurrency.",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="TASKS_TO_MATCHER_CONCURRENCY")
