"""
Configs migration

Generation datetime: 2025-01-20 14:50:31.750653+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "bf1e6d92"
DOWN_REVISION = "3435c359"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
                "luna_video_manager": {"type": "boolean"},
                "luna_video_agent": {"type": "boolean"},
                "luna_streams_retranslator": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
                "luna_video_manager",
                "luna_video_agent",
                "luna_streams_retranslator",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
                "luna_video_manager": {"type": "boolean"},
                "luna_video_agent": {"type": "boolean"},
                "luna_streams_retranslator": {"type": "boolean"},
            },
            "required": [],
            "description": "whether to use nested optional services",
            "additionalProperties": True,
        },
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
            "luna-video-manager",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
            "luna-video-agent",
            "luna-video-manager",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
