"""
Configs migration

Generation datetime: 2025-03-20 07:13:29.621973+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "9dcf50f6"
DOWN_REVISION = "52bdc94d"


def settingUpgradeFunction(oldSetting):
    if oldSetting["db_type"] == "oracle":
        mh.logger.warning(
            f"The *oracle* database support has been terminated. "
            f"The old `LUNA_LAMBDA_DB` setting will be replaced with the new one. The old setting: {oldSetting}"
        )
        return {
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_lambda",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        }
    return oldSetting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_LAMBDA_DB",
        oldValidationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres", "oracle"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": ["db_type", "db_settings"],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": ["db_type", "db_settings"],
            "type": "object",
            "additionalProperties": False,
        },
        settingUpgradeFunction=settingUpgradeFunction,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-lambda"],
        newServices=["luna-lambda"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
